.. include:: /_includes/wip_prolog.rst

:mod:`stix.incident.coa` Module
==================================

.. module:: stix.incident.coa

Classes
-------

.. autoclass:: COATaken
	:show-inheritance:
	:members:

.. autoclass:: COATime
	:show-inheritance:
	:members:
